@@ -1,8 +1,8 @@
 ;;; ntemacs-font.el -- fontsets for Emacs on Windows -*- coding: iso-2022-7bit -*-
 
 ;; Copyright (C) 2004-2007 by T. Hiromatsu <matsuan@users.sourceforge.jp>
-;; Version 1_0_7
-;; 2007-07-22
+;; Version 1_0_10
+;; 2008-02-24
 
 ;;; Commentary:
 
@@ -41,7 +41,7 @@
 ;;      $B$+$iF~<j2DG=$G$9!#(B
 ;;
 ;;----------------------------------------------------------------------
-;; ntemacs-font.el 2007-07-22$BHG(B;;
+;; ntemacs-font.el 2008-02-20$BHG(B;;
 ;;
 ;;  1. Introduction
 ;;  1.1. idea
@@ -50,6 +50,7 @@
 ;;          bold fonts has different width from normal font.
 ;;
 ;;      Defined fontset names are
+;;          lucida (Sans Serif)
 ;;          msgothic (Sans Serif)
 ;;          msmincho (Serif)
 ;;
@@ -191,18 +192,28 @@
 ;;                                                  T.Hiromatsu
 ;;                                                  matsuan@users.sourceforge.jp
 
+(require 'fixed-width-fontset)
+
+;;
+;; emacs version check
+;;
+
+(setq ntemacs-version
+      (cond
+       ((string-match "22\.1\.90\." (eval emacs-version)) 1)
+       ((string-match "22\.1\.91\." (eval emacs-version)) 2)
+       (t 0)))
+
 ;;
 ;; fontset section
 ;;
 
-(require 'fixed-width-fontset)
-
 (defvar fixed-width-encode-reg-alist
   `((latin-iso8859-1 . "iso8859*")
     (latin-iso8859-2 . "iso8859-2")
     (latin-iso8859-3 . "iso10646-1")
     (latin-iso8859-4 . "iso8859-4")
-    (thai-tis620 . "tis620")
+    (thai-tis620 . ,(if (= ntemacs-version 1) "tis620-1" "tis620"))
     (greek-iso8859-7 . "iso10646-1")
     (arabic-iso8859-6 . "iso8859-6")
     (hebrew-iso8859-8 . "iso8859-8")
@@ -211,9 +222,13 @@
     (cyrillic-iso8859-5 . "iso10646-1")
     (latin-iso8859-9 . "iso8859-9")
     (japanese-jisx0208-1978 . "jisx0208.1978")
-    (chinese-gb2312 . "gb2312")
+    (chinese-gb2312 . ,(cond ((= ntemacs-version 0) "gb2312")
+                             ((= ntemacs-version 1) "gb2312.1980-1")
+                             ((= ntemacs-version 2) "gb2312.1980")))
     (japanese-jisx0208 . "jisx0208-sjis")
-    (korean-ksc5601 . "ksc5601.1987")
+    (korean-ksc5601 . ,(cond ((= ntemacs-version 0) "ksc5601.1987")
+                             ((= ntemacs-version 1) "ksc5601.1989-1")
+                             ((= ntemacs-version 2) "ksc5601.1989")))
     (japanese-jisx0212 . "jisx0212")
     (chinese-cns11643-1 . "cns11643.1992-1")
     (chinese-cns11643-2 . "cns11643.1992-2")
@@ -222,8 +237,8 @@
     (chinese-cns11643-5 . "cns11643.1992-5")
     (chinese-cns11643-6 . "cns11643.1992-6")
     (chinese-cns11643-7 . "cns11643.1992-7")
-    (chinese-big5-1 . "big5")
-    (chinese-big5-2 . "big5")
+    (chinese-big5-1 . ,(if (= ntemacs-version 1) "big5-1" "big5"))
+    (chinese-big5-2 . ,(if (= ntemacs-version 1) "big5-1" "big5"))
     (chinese-sisheng . "sisheng_cwnn")
     (vietnamese-viscii-lower . "iso10646-1")
     (vietnamese-viscii-upper . "iso10646-1")
@@ -271,6 +286,9 @@
 (defvar fixed-width-xlfd-template
   "-outline-%s-normal-r-normal-normal-%d-*-*-*-*-*-iso8859-1")
 
+(defvar fixed-width-fontset-template
+  "-*-*-normal-r-normal-normal-%d-*-*-*-*-*-fontset-%s")
+
 (defalias 'fixed-width-create-fontset-func 'create-fontset-from-ascii-font)
 
 ;;
@@ -287,19 +305,27 @@
 
 (set-fontset-font "fontset-default"
                   'chinese-gb2312
-                  '("Arial Unicode MS*" . "gb2312"))
+                  `("Arial Unicode MS*" .
+                    ,(cond ((= ntemacs-version 0) "gb2312")
+                           ((= ntemacs-version 1) "gb2312.1980-1")
+                           ((= ntemacs-version 2) "gb2312.1980"))))
 
 (set-fontset-font "fontset-default"
                   'chinese-big5-1
-                  '("Arial Unicode MS*" . "big5"))
+                  `("Arial Unicode MS*" .
+                    ,(if (= ntemacs-version 1) "big5-1" "big5")))
 
 (set-fontset-font "fontset-default"
                   'korean-ksc5601
-                  '("Arial Unicode MS*" . "ksc5601.1987"))
+                  `("Arial Unicode MS*" .
+                    ,(cond ((= ntemacs-version 0) "ksc5601.1987")
+                           ((= ntemacs-version 1) "ksc5601.1989-1")
+                           ((= ntemacs-version 2) "ksc5601.1989")))) 
 
 (set-fontset-font "fontset-default"
                   'thai-tis620
-                  '("Arial Unicode MS*" . "tis620"))
+                  `("Arial Unicode MS*" .
+                    ,(if (= ntemacs-version 1) "tis620-1" "tis620")))
 
 (set-fontset-font "fontset-default"
                   'mule-unicode-0100-24ff
